@@ -163,6 +163,18 @@ class FarmYearSubsidy(BaseModel):
     policyId: int
     value: float
 
+class FarmYearSubsidyDTO(BaseModel):
+    yearNumber: int
+    value: float
+    policyIdentifier: str
+
+class HolderInfoDTO(BaseModel):
+    holderAge: int
+    holderSuccessorsAge: int
+    holderSuccessors: int
+    holderFamilyMembers: int
+    holderGender: str
+
 class ValueToLPDTO(BaseModel):
     farmId: int
     yearId: int
@@ -174,6 +186,8 @@ class ValueToLPDTO(BaseModel):
     sE410: float
     aversionRiskFactor: float
     m_0: float
+    agentHolder: Optional[HolderInfoDTO] = None
+    agentSubsidies: Optional[List[FarmYearSubsidyDTO]] = None
 
 class CropDataDTO(BaseModel):
     cropProductiveArea: float
@@ -209,11 +223,7 @@ class LivestockDTO(BaseModel):
     milkSellingPrice: float
     variableCosts: float
 
-class HolderInfoDTO(BaseModel):
-    holderAge: int
-    holderSuccessorsAge: int
-    holderSuccessors: int
-    holderFamilyMembers: int
+
 
 class AltitudeEnum(IntEnum):
     MOUNTAINS = 1
